==> haskell-hasql-notifications-0.2.0.5-79.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-1dpUctTVyay3DdEG4r8MDm
key:                  hasql-notifications-0.2.0.5-1dpUctTVyay3DdEG4r8MDm
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  412be1b46590cc1b69d92f1e8fd3daf8
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-1dpUctTVyay3DdEG4r8MDm
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-D13dwG1Hnoj5UOBosN4Mcc
    hasql-pool-0.5.2.2-HxfrSKcGj0MQHhb0GROcK
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-notifications-0.2.0.5-80-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-HWsTSc6EM28E6Mho3HnUgG
key:                  hasql-notifications-0.2.0.5-HWsTSc6EM28E6Mho3HnUgG
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  5765c51321045527dd65061033796051
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-HWsTSc6EM28E6Mho3HnUgG
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-D56QxJSATLi7EO6Br9LDFG
    hasql-pool-0.5.2.2-E9pZt3MsMInGPVym8tUiYi
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
